setwd('C:/Thibaut/_AMI_2020/oiseaux_mayotte/crabier/article/scripts')

library(tidyverse)
library(RMark)

# import nest detection histories
Mayotte <- convert.inp(paste("../data/cmr_dataset_year1",sep="/"),
                       group.df = data.frame(colony=c("Chiconi","Ironibe")))

Mayotte<-Mayotte[,1:3]

# CMR models
Mayotte.proc <- process.data(Mayotte, 
                             begin.time = 1, 
                             model = "FullHet",
                             groups="colony")
Mayotte.ddl <- make.design.data(Mayotte.proc)


run.Mayotte <- function() {
  # List of effects 
  p.dot <- list(p = list(formula =  ~ 1, share = TRUE), f0 = list(formula =  ~ colony)) # M0 : p constant over time, f0 varies between groups
  p.time <- list(p = list(formula =  ~ time, share = TRUE), f0 = list(formula =  ~ colony)) # Mt : p varies over time, f0 varies between groups
  p.col <- list(p =list(formula = ~ colony, share = TRUE), f0 = list(formula =  ~ colony)) # Mg : p varies between groups, f0 varies between groups
  p.time.col <- list(p =list(formula = ~ time + colony, share = TRUE), f0 = list(formula =  ~ colony)) # Mgt : p varies over time and between groups, f0 varies between groups
  ## Build model list
  Mayotte.model.list <- create.model.list("FullHet")
  ## Prepare list to send to Mark
  Mayotte.results <- mark.wrapper(Mayotte.model.list,data = Mayotte.proc,ddl = Mayotte.ddl)
  ## Grab results
  return(Mayotte.results)
}

Mayotte.results <- run.Mayotte()

Mayotte.results
names(Mayotte.results)


# Predictions time-dependent model (best AIC score)

## Population size
Mayotte.results$p.time$results$real
Mayotte.results$p.time$results$derived

res<-as.data.frame(Mayotte.results$p.time$results$derived)
res<-bind_cols(Mayotte.results$p.time$data$group.covariates, res)


## Detection probability
res2<-as.data.frame(Mayotte.results$p.time$results$real)
tab<-res2[2:7,c(1,3,4)]

hour<-c(7,9,11,13,15,17)
tab<-cbind(hour,tab)
tab<-as.data.frame(tab)

tab %>%
  ggplot() +
  theme_bw() +
  geom_histogram(aes(x=hour, y = estimate), fill="forestgreen", color="black", alpha=.4, stat = "identity") +
  geom_errorbar(aes(x=hour, y=estimate, ymin=lcl, ymax=ucl), width=.2, size=0.7, position=position_dodge(.9)) +
  theme(axis.title.x = element_text(size = 13),
        axis.title.y = element_text(size = 13),
        axis.text.x = element_text(size=13), 
        axis.text.y = element_text(size = 11),
        legend.title = element_text(colour="black", size=10),
        legend.text = element_text(size=11)) +
  xlab("hour") + 
  ylab("detection probability (p)") 

