setwd('C:/Thibaut/_AMI_2020/oiseaux_mayotte/crabier/article/scripts')

library(tidyverse)
library(RMark)

# import nest detection histories
Mayotte <- convert.inp(paste("../data/cmr_dataset_year2",sep="/"),
                       group.df = data.frame(colony=c("Bouyouni","Chiconi","Ironibe","Malamani","Mronabeja")),
                       covariates = 2)

Mayotte<-Mayotte[,1:3]

# CMR models
Mayotte.proc <- process.data(Mayotte, 
                             begin.time = 1, 
                             model = "FullHet",
                             groups="colony")
Mayotte.ddl <- make.design.data(Mayotte.proc)


run.Mayotte <- function() {
  # List of effects 
  p.dot <- list(p = list(formula =  ~ 1, share = TRUE), f0 = list(formula =  ~ colony)) # M0 : p constant over time, f0 varies between groups
  p.time <- list(p = list(formula =  ~ time, share = TRUE), f0 = list(formula =  ~ colony)) # Mt : p varies over time, f0 varies between groups
  p.col <- list(p =list(formula = ~ colony, share = TRUE), f0 = list(formula =  ~ colony)) # Mg : p varies between groups, f0 varies between groups
  p.time.col <- list(p =list(formula = ~ time + colony, share = TRUE), f0 = list(formula =  ~ colony)) # Mgt : p varies over time and between groups, f0 varies between groups
  ## Build model list
  Mayotte.model.list <- create.model.list("FullHet")
  ## Prepare list to send to Mark
  Mayotte.results <- mark.wrapper(Mayotte.model.list,data = Mayotte.proc,ddl = Mayotte.ddl)
  ## Grab results
  return(Mayotte.results)
}

Mayotte.results <- run.Mayotte()

Mayotte.results
names(Mayotte.results)


# Predictions time-dependent model (best AIC score)

## Population size
Mayotte.results$p.time$results$real
Mayotte.results$p.time$results$derived

res<-as.data.frame(Mayotte.results$p.time$results$derived)
res<-bind_cols(Mayotte.results$p.time$data$group.covariates, res)

res %>%
  ggplot() +
  theme_bw() +
  geom_histogram(aes(x=colony, y = N.Population.Size.estimate), fill="yellow", color="black", alpha=.4, stat = "Identity") +
  geom_errorbar(aes(x=colony, y=N.Population.Size.estimate, ymin=N.Population.Size.lcl, ymax=N.Population.Size.ucl), width=.2, size=0.7, position=position_dodge(.9)) +
  theme(axis.title.x = element_text(size = 15),
        axis.title.y = element_text(size = 15),
        axis.text.x = element_text(size=14), 
        axis.text.y = element_text(size = 14),
        legend.title = element_text(colour="black", size=11),
        legend.text = element_text(size=12)) +
  xlab("colony") + 
  ylab("abundance estimate (N)") 


## Detection probability

res2<-as.data.frame(Mayotte.results$p.time$results$real)
tab<-res2[2:4,c(1,3,4)]

visit<-c(1,2,3)
tab<-cbind(visit,tab)
tab<-as.data.frame(tab)


# Predictions constant model

## Detection probability

res3<-as.data.frame(Mayotte.results$p.dot$results$real)
tab_res3<-res3[2,c(1,3,4)]
tab_res3<-as.data.frame(tab_res3)
tab_res3

