setwd('C:/Thibaut/_AMI_2020/oiseaux_mayotte/crabier/article/scripts')

library(tidyverse)
library(lubridate)
library(mgcv)
library(tidymv)

# data importation & manipulation
data_journ <- readr::read_csv2("../data/counts_year1.csv")
data_journ %>%
  dplyr::mutate(Jour = dmy(Jour),
                Jour_an = yday(Jour),
                periode=case_when(Jour_an %in% c(289,296) ~ 1,
                                  Jour_an %in% c(332,339) ~ 2,
                                  Jour_an %in% c(15,22) ~ 3),
                Colonie = as.factor(Colonie),
                heure = as.numeric(Heure),
                Heure = as.factor(Heure),
                session=as.factor(periode),
                periodeq=periode^2) -> data_journ 

# GAM on adult counts
GAM_ad<-gam(Nbr_Adulte ~
             session  +
             s(heure, by = session, k=6),
           data=data_journ, family=poisson)

# plot GAM
plot_smooths(
  model = GAM_ad,
  series = heure,
  transform = exp,
  #facet_terms = Colonie
  comparison = session
) +
  theme_bw() +
  theme(legend.position = "none",
        axis.title.x = element_text(size = 12),
        axis.title.y = element_text(size = 12),
        axis.text.x = element_text(size=11), 
        axis.text.y = element_text(size = 11),
        legend.title = element_text(colour="black", size=9),
        legend.text = element_text(size=8)) +
  xlab("hour") +
  ylab("relative abundance") +
  scale_x_continuous(breaks=c(7,9,11, 13, 15, 17))

# GAM on juvenile counts
GAM_juvs<-gam(Nbr_Jeune ~
             session  +
             s(heure, by = session, k=6),
           data=data_journ, family=poisson)

# plot GAM
plot_smooths(
  model = GAM_juvs,
  series = heure,
  #facet_terms = Colonie
  transform = exp,
  comparison = session
) +
  theme_bw() +
  theme(legend.position = "right",
        axis.title.x = element_text(size = 12),
        axis.title.y = element_text(size = 12),
        axis.text.x = element_text(size=11), 
        axis.text.y = element_text(size = 11),
        legend.title = element_text(colour="black", size=11),
        legend.text = element_text(size=10)) +
  xlab("hour") +
  ylab("relative abundance") +
  scale_x_continuous(breaks=c(7,9,11, 13, 15, 17))
