setwd('C:/Thibaut/_AMI_2020/oiseaux_mayotte/crabier/article/scripts/simulations')
library(RMark)
library(tidyverse)


# function to create capture history character strings (need for input to RMARK)

pasty <- function(x){
  k <- ncol(x)
  n <- nrow(x)
  out <- array(dim=n)
  for(i in 1:n){
    out[i] <- paste(x[i,], collapse="")
  }
  return(out)      }




################## example with colony abundance N = 50 ; nb of visits k = 2


# Define function to simulate data under M0 (from Kery book)
data.fn <- function(N = 50, p = 0.6, T = 2){
  yfull <- yobs <- array(NA, dim = c(N, T) )
  for (j in 1:T){
    yfull[,j] <- rbinom(n = N, size = 1, prob = p)
  }
  ever.detected <- apply(yfull, 1, max)
  124
  C <- sum(ever.detected)
  yobs <- yfull[ever.detected == 1,]
  cat(C, "out of", N, "animals present were detected.\n")
  return(list(N = N, p = p, C = C, T = T, yfull = yfull, yobs = yobs))
}



###############################
# parameters for simulations


nbsimul=100 # number of simulations for each capture occasion k



###############################
# matrix to fulfill values from loops
res_simul<-matrix(NA,nrow=nbsimul,ncol=5)



# loops

for (simul in 1:nbsimul)
{
  
  data <- data.fn()
  chprov<-pasty(data$yobs)
  
  
  # data for RMARK
  data <- data.frame(ch = chprov)
  model.1=mark(data = data, model="Closed")
  
  
  # matrix fulfill with values from loops
  res_simul[simul,1]<-model.1$results$derived$'N Population Size'$estimate
  res_simul[simul,2]<-model.1$results$derived$'N Population Size'$se
  res_simul[simul,3]<-(res_simul[simul,2]/res_simul[simul,1])
  res_simul[simul,4]<-model.1$results$derived$'N Population Size'$lcl
  res_simul[simul,5]<-model.1$results$derived$'N Population Size'$ucl
  
}

colnames(res_simul)<-c('N', 'se', 'cv', 'lcl','ucl')

res_simul %>%
  as_tibble() %>%
  mutate(d1= case_when((N-N*1/100<lcl) ~ 1, TRUE~0),
         d2= case_when((N-N*2/100<lcl) ~ 1, TRUE~0),
         d3= case_when((N-N*3/100<lcl) ~ 1, TRUE~0),
         d4= case_when((N-N*4/100<lcl) ~ 1, TRUE~0),
         d5= case_when((N-N*5/100<lcl) ~ 1, TRUE~0),
         d6= case_when((N-N*6/100<lcl) ~ 1, TRUE~0),
         d7= case_when((N-N*7/100<lcl) ~ 1, TRUE~0),
         d8= case_when((N-N*8/100<lcl) ~ 1, TRUE~0),
         d9= case_when((N-N*9/100<lcl) ~ 1, TRUE~0),
         d10= case_when((N-N*10/100<lcl) ~ 1, TRUE~0),
         d11= case_when((N-N*11/100<lcl) ~ 1, TRUE~0),
         d12= case_when((N-N*12/100<lcl) ~ 1, TRUE~0),
         d13= case_when((N-N*13/100<lcl) ~ 1, TRUE~0),
         d14= case_when((N-N*14/100<lcl) ~ 1, TRUE~0),
         d15= case_when((N-N*15/100<lcl) ~ 1, TRUE~0),
         d16= case_when((N-N*16/100<lcl) ~ 1, TRUE~0),
         d17= case_when((N-N*17/100<lcl) ~ 1, TRUE~0),
         d18= case_when((N-N*18/100<lcl) ~ 1, TRUE~0),
         d19= case_when((N-N*19/100<lcl) ~ 1, TRUE~0),
         d20= case_when((N-N*20/100<lcl) ~ 1, TRUE~0),
         col=50) %>%
  group_by(col) %>%
  summarise(CV_mean=mean(cv),
            nsimul=n(),
            dec1=sum(d1)/nsimul,
            dec2=sum(d2)/nsimul,
            dec3=sum(d3)/nsimul,
            dec4=sum(d4)/nsimul,
            dec5=sum(d5)/nsimul,
            dec6=sum(d6)/nsimul,
            dec7=sum(d7)/nsimul,
            dec8=sum(d8)/nsimul,
            dec9=sum(d9)/nsimul,
            dec10=sum(d10)/nsimul,
            dec11=sum(d11)/nsimul,
            dec12=sum(d12)/nsimul,
            dec13=sum(d13)/nsimul,
            dec14=sum(d14)/nsimul,
            dec15=sum(d15)/nsimul,
            dec16=sum(d16)/nsimul,
            dec17=sum(d17)/nsimul,
            dec18=sum(d18)/nsimul,
            dec19=sum(d19)/nsimul,
            dec20=sum(d20)/nsimul) -> N50_k2


